Formatting your configuration
=============================

The format specified below is typical of what you should have in your .env.py file.

     .. code-block:: python

        DBNAME = "sector_seven"
        DB_USER = "homer_simpson"
        DB_PASSWORD = "Close, but you're way off."
